package metier;
import java.util.Objects;
import javax.swing.Icon;
import javax.swing.JOptionPane;

/**
 * Classe Guerrier, hérite de la classe Personnage
 * @author Dominique_2
 * @version 20170115
 */
public class Guerrier extends Personnage{
    // Variable membre
    private String arme;

    /**
     * Valorisation des variables membres
     * @param nom       nom du guerrier
     * @param img       nom de l'image représentant le guerrier
     * @param energie   valeur énergétique du guerrier
     * @param dureeVie  durée de vie du guerrier
     * @param arme      armu du guerrier
     */
    public Guerrier(String nom, String img, int energie, int dureeVie, String arme) {
        super(nom, img, energie, dureeVie);
        this.arme = arme;
    }
    /**
     * Permet d'obtenir les valeurs des attributs de l'objet courant
     * @return liste des attributs avec leurs valeurs
     */
    @Override
    public String toString() {
        return super.toString() + "\tArme=" + arme;
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = super.hashCode() + (13 * hash + Objects.hashCode(this.arme));
        return hash;
    }
    /**
     * Comparaison de l'objet courant avec l'objet passé en paramètre
     * @param obj objet à comparer avec l'objet courant
     * @return true : les 2 objets sont identiques, false sinon
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Guerrier other = (Guerrier) obj;
        if (!Objects.equals(this.arme, other.arme)) {
            return false;
        }
        if(!super.equals(obj)){
            return false;
        }
        return true;
    }

    /**
     * Get the value of arme
     *
     * @return the value of arme
     */
    public String getArme() {
        return arme;
    }

    /**
     * Set the value of arme
     *
     * @param arme new value of arme
     */
    public void setArme(String arme) {
        this.arme = arme;
    }
    
    /**
     * Initie la rencontre avec un autre personnage
     * @param unPerso un Personnage
     * @return Message de rencontre
     */
    public String rencontrer(Personnage unPerso) {
        String titre = this.getNom() + " rencontre " + unPerso.getNom() + " : Jeu de dés";
        String message = "Es-tu prêt à me combattre "+ unPerso.getNom() +" ?";
        Icon ImgDe = new javax.swing.ImageIcon(getClass().getResource("/img/des.jpg"));
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE, ImgDe);
        
        int Attaquant = Jeu.genererNbAleatoire(1, 100);
        int Defenseur = Jeu.genererNbAleatoire(1, 100);
        message = this.getNom()+": "+Attaquant+" - "+ unPerso.getNom() +": "+ Defenseur +"\n\n";
        Icon ImgVainqueur;
        if (Attaquant > Defenseur) {
            message += this.getNom() +" l'emporte !\n\n";
            ImgVainqueur = new javax.swing.ImageIcon(getClass().getResource("/img/"+ this.getNom() +".jpg"));
            unPerso.setEnergie(unPerso.getEnergie()-2);
            unPerso.setDureeVie(unPerso.getDureeVie()-1);
        } else if (Defenseur > Attaquant) {
            message += unPerso.getNom() +" l'emporte !\n\n";
            ImgVainqueur = new javax.swing.ImageIcon(getClass().getResource("/img/"+ unPerso.getNom() +".jpg"));
            this.setEnergie(this.getEnergie()-1);
            unPerso.setEnergie(unPerso.getEnergie()+2);
        } else {
            ImgVainqueur = null;
            message += "Il y a égalité entre les parties !\n\n";
        }
        message += this.getNom() +": "+ this.getDureeVie()+" - "+ unPerso.getNom() +": "+ unPerso.getDureeVie();
        
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE, ImgVainqueur);
        //Icon imgPerso = new javax.swing.ImageIcon(getClass().getResource("/img/" + this.getImg()));
        //JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE, imgPerso);       
        return message;
    }
    
    /**
      * Saluer un personnage
      * @param unPerso Un personnage
      * @return Message de salutation
      */
    @Override
    public String saluer(Personnage unPerso) {
        String titre = this.getNom() + " salue " + unPerso.getNom();
        String message = "Bonjour " + unPerso.getNom() + " , sauve-toi vite avant que je ne te frappe avec mon arme redoutable !";
        //JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE);
        Icon imgPerso = new javax.swing.ImageIcon(getClass().getResource("/img/" + this.getImg()));
        JOptionPane.showMessageDialog(null, message, titre, JOptionPane.INFORMATION_MESSAGE, imgPerso);       
        return message;
    }
}
